#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.4.20
id: yesod-core-1.4.20-0795e5dd1fccda51b978355252f3f0a8
key: yesod_DMXQXRCFyKJ7uwt7JGWF70
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Json Yesod.Core.Widget
    Yesod.Core.Internal Yesod.Core.Types Yesod.Core.Unsafe
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.20
hs-libraries: HSyesod-core-1.4.20-DMXQXRCFyKJ7uwt7JGWF70
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
    wai-extra-3.0.15-2f88b45989ced36024c3ff3943866d23
    wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
    warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
